@@ -44,6 +44,8 @@ else:
 __all__ = (
     "BatchDeleteRecipeVersionRequestRequestTypeDef",
     "BatchDeleteRecipeVersionResponseTypeDef",
+    "ColumnSelectorTypeDef",
+    "ColumnStatisticsConfigurationTypeDef",
     "ConditionExpressionTypeDef",
     "CreateDatasetRequestRequestTypeDef",
     "CreateDatasetResponseTypeDef",
@@ -62,6 +64,7 @@ __all__ = (
     "DataCatalogInputDefinitionTypeDef",
     "DataCatalogOutputTypeDef",
     "DatabaseInputDefinitionTypeDef",
+    "DatabaseOutputTypeDef",
     "DatabaseTableOutputOptionsTypeDef",
     "DatasetParameterTypeDef",
     "DatasetTypeDef",
@@ -117,6 +120,7 @@ __all__ = (
     "OutputTypeDef",
     "PaginatorConfigTypeDef",
     "PathOptionsTypeDef",
+    "ProfileConfigurationTypeDef",
     "ProjectTypeDef",
     "PublishRecipeRequestRequestTypeDef",
     "PublishRecipeResponseTypeDef",
@@ -136,6 +140,8 @@ __all__ = (
     "StartJobRunResponseTypeDef",
     "StartProjectSessionRequestRequestTypeDef",
     "StartProjectSessionResponseTypeDef",
+    "StatisticOverrideTypeDef",
+    "StatisticsConfigurationTypeDef",
     "StopJobRunRequestRequestTypeDef",
     "StopJobRunResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -172,6 +178,36 @@ BatchDeleteRecipeVersionResponseTypeDef = TypedDict(
     },
 )
 
+ColumnSelectorTypeDef = TypedDict(
+    "ColumnSelectorTypeDef",
+    {
+        "Regex": str,
+        "Name": str,
+    },
+    total=False,
+)
+
+_RequiredColumnStatisticsConfigurationTypeDef = TypedDict(
+    "_RequiredColumnStatisticsConfigurationTypeDef",
+    {
+        "Statistics": "StatisticsConfigurationTypeDef",
+    },
+)
+_OptionalColumnStatisticsConfigurationTypeDef = TypedDict(
+    "_OptionalColumnStatisticsConfigurationTypeDef",
+    {
+        "Selectors": List["ColumnSelectorTypeDef"],
+    },
+    total=False,
+)
+
+
+class ColumnStatisticsConfigurationTypeDef(
+    _RequiredColumnStatisticsConfigurationTypeDef, _OptionalColumnStatisticsConfigurationTypeDef
+):
+    pass
+
+
 _RequiredConditionExpressionTypeDef = TypedDict(
     "_RequiredConditionExpressionTypeDef",
     {
@@ -244,6 +280,7 @@ _OptionalCreateProfileJobRequestRequestTypeDef = TypedDict(
         "LogSubscription": LogSubscriptionType,
         "MaxCapacity": int,
         "MaxRetries": int,
+        "Configuration": "ProfileConfigurationTypeDef",
         "Tags": Dict[str, str],
         "Timeout": int,
         "JobSample": "JobSampleTypeDef",
@@ -317,6 +354,7 @@ _OptionalCreateRecipeJobRequestRequestTypeDef = TypedDict(
         "MaxRetries": int,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "ProjectName": str,
         "RecipeReference": "RecipeReferenceTypeDef",
         "Tags": Dict[str, str],
@@ -489,6 +527,26 @@ class DatabaseInputDefinitionTypeDef(
     pass
 
 
+_RequiredDatabaseOutputTypeDef = TypedDict(
+    "_RequiredDatabaseOutputTypeDef",
+    {
+        "GlueConnectionName": str,
+        "DatabaseOptions": "DatabaseTableOutputOptionsTypeDef",
+    },
+)
+_OptionalDatabaseOutputTypeDef = TypedDict(
+    "_OptionalDatabaseOutputTypeDef",
+    {
+        "DatabaseOutputMode": Literal["NEW_TABLE"],
+    },
+    total=False,
+)
+
+
+class DatabaseOutputTypeDef(_RequiredDatabaseOutputTypeDef, _OptionalDatabaseOutputTypeDef):
+    pass
+
+
 _RequiredDatabaseTableOutputOptionsTypeDef = TypedDict(
     "_RequiredDatabaseTableOutputOptionsTypeDef",
     {
@@ -709,7 +767,9 @@ DescribeJobResponseTypeDef = TypedDict(
         "MaxRetries": int,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "ProjectName": str,
+        "ProfileConfiguration": "ProfileConfigurationTypeDef",
         "RecipeReference": "RecipeReferenceTypeDef",
         "ResourceArn": str,
         "RoleArn": str,
@@ -737,12 +797,14 @@ DescribeJobRunResponseTypeDef = TypedDict(
         "ErrorMessage": str,
         "ExecutionTime": int,
         "JobName": str,
+        "ProfileConfiguration": "ProfileConfigurationTypeDef",
         "RunId": str,
         "State": JobRunStateType,
         "LogSubscription": LogSubscriptionType,
         "LogGroupName": str,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "RecipeReference": "RecipeReferenceTypeDef",
         "StartedBy": str,
         "StartedOn": datetime,
@@ -916,6 +978,7 @@ JobRunTypeDef = TypedDict(
         "LogGroupName": str,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "RecipeReference": "RecipeReferenceTypeDef",
         "StartedBy": str,
         "StartedOn": datetime,
@@ -956,6 +1019,7 @@ _OptionalJobTypeDef = TypedDict(
         "MaxRetries": int,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "ProjectName": str,
         "RecipeReference": "RecipeReferenceTypeDef",
         "ResourceArn": str,
@@ -1203,6 +1267,16 @@ PathOptionsTypeDef = TypedDict(
     total=False,
 )
 
+ProfileConfigurationTypeDef = TypedDict(
+    "ProfileConfigurationTypeDef",
+    {
+        "DatasetStatisticsConfiguration": "StatisticsConfigurationTypeDef",
+        "ProfileColumns": List["ColumnSelectorTypeDef"],
+        "ColumnStatisticsConfigurations": List["ColumnStatisticsConfigurationTypeDef"],
+    },
+    total=False,
+)
+
 _RequiredProjectTypeDef = TypedDict(
     "_RequiredProjectTypeDef",
     {
@@ -1525,6 +1599,23 @@ StartProjectSessionResponseTypeDef = TypedDict(
     },
 )
 
+StatisticOverrideTypeDef = TypedDict(
+    "StatisticOverrideTypeDef",
+    {
+        "Statistic": str,
+        "Parameters": Dict[str, str],
+    },
+)
+
+StatisticsConfigurationTypeDef = TypedDict(
+    "StatisticsConfigurationTypeDef",
+    {
+        "IncludedStatistics": List[str],
+        "Overrides": List["StatisticOverrideTypeDef"],
+    },
+    total=False,
+)
+
 StopJobRunRequestRequestTypeDef = TypedDict(
     "StopJobRunRequestRequestTypeDef",
     {
@@ -1600,6 +1691,7 @@ _RequiredUpdateProfileJobRequestRequestTypeDef = TypedDict(
 _OptionalUpdateProfileJobRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateProfileJobRequestRequestTypeDef",
     {
+        "Configuration": "ProfileConfigurationTypeDef",
         "EncryptionKeyArn": str,
         "EncryptionMode": EncryptionModeType,
         "LogSubscription": LogSubscriptionType,
@@ -1674,6 +1766,7 @@ _OptionalUpdateRecipeJobRequestRequestTypeDef = TypedDict(
         "MaxRetries": int,
         "Outputs": List["OutputTypeDef"],
         "DataCatalogOutputs": List["DataCatalogOutputTypeDef"],
+        "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "Timeout": int,
     },
     total=False,
